@@ -5,3 +5,7 @@
 #' @inheritParams strex::str_give_ext
 #' @export
 give_ext <- strex::str_give_ext
+
+#' @rdname give_ext
+#' @export
+str_give_ext <- give_ext
